@@ -2,7 +2,7 @@
 """
 Expose a CloudFileFS object over SFTP using paramiko
 
-Copyright (C) 2011-2013 by Memset Ltd. http://www.memset.com/
+Copyright (C) 2011-2014 by Memset Ltd. http://www.memset.com/
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -34,7 +34,7 @@ from SocketServer import StreamRequestHandler, ForkingTCPServer
 import paramiko
 from Crypto import Random
 
-from ftpcloudfs.fs import ObjectStorageFS
+from ftpcloudfs.fs import ObjectStorageFS, ObjectStorageFD
 from ftpcloudfs.utils import smart_str
 from sftpcloudfs.scp import SCPHandler
 
@@ -254,14 +254,15 @@ class ObjectStorageSFTPServer(ForkingTCPServer, paramiko.ServerInterface):
     """
     allow_reuse_address = True
 
-    def __init__(self, address, host_key=None, authurl=None, max_children=20, keystone=None, no_scp=False):
+    def __init__(self, address, host_key=None, authurl=None, max_children=20, keystone=None, no_scp=False, split_size=0, hide_part_dir=False):
         self.log = paramiko.util.get_logger("paramiko")
         self.log.debug("%s: start server" % self.__class__.__name__)
-        self.fs = ObjectStorageFS(None, None, authurl=authurl, keystone=keystone) # unauthorized
+        self.fs = ObjectStorageFS(None, None, authurl=authurl, keystone=keystone, hide_part_dir=hide_part_dir) # unauthorized
         self.host_key = host_key
         self.max_children = max_children
         self.no_scp = no_scp
         ForkingTCPServer.__init__(self, address, ObjectStorageSFTPRequestHandler)
+        ObjectStorageFD.split_size = split_size
 
     def check_channel_request(self, kind, chanid):
         if kind == 'session':
